@@ -1,3 +1,3 @@
 from .primes import lcm
-from .primes import primes
+from .primes import PrimeNumbers
 from .primes import primesieve
\ No newline at end of file
